@@ -32,37 +32,6 @@
 #include "gedit-app.h"
 #include "gedit-dirs.h"
 
-void
-_gedit_cmd_help_keyboard_shortcuts (GeditWindow *window)
-{
-	static GtkWidget *shortcuts_window;
-
-	gedit_debug (DEBUG_COMMANDS);
-
-	if (shortcuts_window == NULL)
-	{
-		GtkBuilder *builder;
-
-		builder = gtk_builder_new_from_resource ("/org/gnome/gedit/ui/gedit-shortcuts.ui");
-		shortcuts_window = GTK_WIDGET (gtk_builder_get_object (builder, "shortcuts-gedit"));
-
-		g_signal_connect (shortcuts_window,
-				  "destroy",
-				  G_CALLBACK (gtk_widget_destroyed),
-				  &shortcuts_window);
-
-		g_object_unref (builder);
-	}
-
-	if (GTK_WINDOW (window) != gtk_window_get_transient_for (GTK_WINDOW (shortcuts_window)))
-	{
-		gtk_window_set_transient_for (GTK_WINDOW (shortcuts_window), GTK_WINDOW (window));
-	}
-
-	gtk_widget_show_all (shortcuts_window);
-	gtk_window_present (GTK_WINDOW (shortcuts_window));
-}
-
 void
 _gedit_cmd_help_contents (GeditWindow *window)
 {
